@@ -30,7 +30,7 @@ import (
 
 const EnvInodeNoTrust = "REDO_INODE_NO_TRUST"
 
-var InodeTrust bool = false
+var InodeTrust = false
 
 type Inode struct {
 	Size      int64
