@@ -59,7 +59,7 @@ var (
 	CWarn  string
 	CJS    string
 	CReset string
-	CNone  string = "NONE"
+	CNone  = "NONE"
 
 	flagDebug      = flag.Bool("d", false, fmt.Sprintf("enable debug logging (%s=1)", EnvDebug))
 	flagNoProgress *bool
@@ -108,7 +108,7 @@ func erasedStatus(s, end string) string {
 	return s + KeyEraseLine + end
 }
 
-func trace(level, format string, args ...interface{}) {
+func tracef(level, format string, args ...interface{}) {
 	var p string
 	if MyPid != 0 {
 		p = fmt.Sprintf("[%d] ", MyPid)
